package imports

import (
	"database/sql"
	"log"
)

func checkColorExists(db *sql.DB, abbrev string) bool {
	query := "SELECT Id FROM Color WHERE Abbreviation = ?;"

	var colorId int
	row := db.QueryRow(query, abbrev)
	err := row.Scan(&colorId)

	if err == sql.ErrNoRows {
		return false
	} else if err != nil {
		log.Fatal(err)
	}

	return true
}

func insertColor(db *sql.DB, color string, abbrev string) error {
	query := `INSERT INTO Color (Name, Abbreviation) VALUES (?, ?);`

	insert, err := db.Prepare(query)
	defer insert.Close()
	if err != nil {
		return err
	}

	result, err := insert.Exec(color, abbrev)
	rowsAffected, err := result.RowsAffected()
	if err != nil || rowsAffected != 1 {
		return err
	}

	return nil
}

func InsertColors(db *sql.DB) error {
	colors := map[string]string{
		"White": "W",
		"Blue":  "U",
		"Black": "B",
		"Red":   "R",
		"Green": "G",
	}

	for name, abbrev := range colors {
		if checkColorExists(db, abbrev) {
			log.Println("[Color] Skipping " + name + ", already in database")
			continue
		}

		err := insertColor(db, name, abbrev)
		if err != nil {
			return err
		}
	}

	return nil
}
